@@ -93,11 +93,18 @@ gower <- function(d.mat) {
 }
 
 #' Function to the hat matrix
+#' @param X A \eqn{n x p} matrix or data frame of predictors.
 .hat <- function(X) {
   tcrossprod(tcrossprod(X, solve(crossprod(X))), X)
 }
 
 #' Function to compute test statistics for a permuted design matrix
+#' @param X A \eqn{n x p} matrix or data frame of predictors.
+#' @param n sample size
+#' @param vg Computational details (internal function)
+#' @param trG trace of G
+#' @param px Computational details (internal function)
+#' @param test.inds Computational details (internal function)
 .mdmr.permstats <- function(X, n, vg, trG, px, test.inds) {
   # Permute rows of X
   perm.indices <- sample(1:n, size = n, replace = F)
@@ -127,6 +134,12 @@ gower <- function(d.mat) {
 }
 
 #' function to compute pseudo R-square
+#' @param G Gower's centered similarity matrix computed from \code{D}.
+#' Either \code{D} or \code{G} must be passed to \code{mdmr}.
+#' @param vh Computational details (internal function)
+#' @param vhs Computational trick (internal function)
+#' @param x.inds Computational trick (internal function)
+#' @param unique.xnames Computational details (internal function)
 .pseudo.r2 <- function(G, vh, vhs, x.inds, unique.xnames = NULL) {
 
   # =========================== Omnibus Test =============================== #
@@ -200,7 +213,7 @@ gower <- function(d.mat) {
 #' @param return.lambda Logical; indicates whether or not the eigenvalues of
 #' \code{G} should be returned, if calculated. Default is \code{FALSE}.
 #' @param start.acc Starting accuracy of the Davies (1980) algorithm
-#' implemented in the \code{\link{davies}} function in the \code{CompQuadForm}
+#' implemented in the \code{\link[CompQuadForm]{davies}} function in the \code{CompQuadForm}
 #' package (Duchesne &  De Micheaux, 2010) that \code{mdmr()} uses to compute
 #' MDMR p-values.
 #' @param ncores Integer; if \code{ncores} > 1, the \code{\link{parallel}}
@@ -1272,8 +1285,8 @@ delta <- function(X, Y = NULL, dtype = NULL, niter = 10,
 #' independence assumption. This is done by invoking a mixed-effects modeling
 #' framework, in which clustering/grouping variables are specified as random
 #' effects and the covariate effects of interest are fixed effects. The input
-#' to \code{mixed.mdmr} largely reflects the input of the \code{\link{lmer}}
-#' function from the package \code{\link{lme4}} insofar as the specification of
+#' to \code{mixed.mdmr} largely reflects the input of the \code{\link[lme4]{lmer}}
+#' function from the package \code{\link[lme4]{lme4}} insofar as the specification of
 #' random and fixed effects are concerned (see Arguments for details). Note that
 #' this function simply controls for the random effects in order to test the
 #' fixed effects; it does not facilitate point estimation or inference on the
@@ -1295,7 +1308,7 @@ delta <- function(X, Y = NULL, dtype = NULL, niter = 10,
 #' computational burden of \code{mixed.mdmr} is small, so \code{use.ssd} should
 #' be set to 1.00.
 #' @param start.acc Starting accuracy of the Davies (1980) algorithm
-#' implemented in the \code{\link{davies}} function in the \code{CompQuadForm}
+#' implemented in the \code{\link[CompQuadForm]{davies}} function in the \code{CompQuadForm}
 #' package (Duchesne &  De Micheaux, 2010) that \code{mdmr()} uses to compute
 #' MDMR p-values.
 #' @param ncores Integer; if \code{ncores} > 1, the \code{\link{parallel}}
@@ -1432,11 +1445,11 @@ mixed.mdmr <- function(fmla, data,
   # ============================================================================
   # Step 1c:   Outcome management
   # ============================================================================
-  if(class(D) != "dist") {
-    if(class(D) != "matrix") {
+  if(!inherits(D, "dist")) {
+    if(!inherits(D, "matrix")) {
       stop("Please pass a distance object or an n x n matrix to D")
     }
-    if(class(D) == "matrix") {
+    if(inherits(D, "matrix")) {
       if(nrow(D) != ncol(D)) {
         stop("Please pass a distance object or an n x n matrix to D")
       }
